using SkiaSharp;
using System;

namespace Ryujinx.Graphics.Gpu
{
    /// <summary>
    /// Interface for overlay management functionality
    /// </summary>
    public interface IOverlayManager : IDisposable
    {
        /// <summary>
        /// Add an overlay to the manager
        /// </summary>
        /// <param name="overlay">The overlay to add</param>
        void AddOverlay(IOverlay overlay);

        /// <summary>
        /// Update all overlays (for animations)
        /// </summary>
        /// <param name="deltaTime">Time elapsed since last update</param>
        /// <param name="screenSize">Current screen size</param>
        void Update(float deltaTime, SKSize screenSize = default);

        /// <summary>
        /// Render all visible overlays
        /// </summary>
        /// <param name="canvas">The canvas to render to</param>
        void Render(SKCanvas canvas);
    }
} 
